@@ -11,7 +11,8 @@ import requests
 from datetime import datetime
 
 from tcsoa.config import TcSoaConfig
-from tcsoa.exceptions import InvalidCredentialsException, InternalServerException, ServiceException, Severity
+from tcsoa.exceptions import InvalidCredentialsException, InternalServerException, ServiceException, Severity, \
+    InnerException
 from tcsoa.gen.Server import ServiceData
 from tcsoa.base import TcBoClass
 
@@ -62,7 +63,7 @@ class RestBackend:
     def add_object_load_policy(self, bo_name, properties: List[str]):
         object_policy = self._get_object_load_policy_for_bo(bo_name)
         for prop in properties:
-            if not any(p for p in object_policy['properties'] if next(iter(p.values())) == prop):
+            if not any(p for p in object_policy.get('properties', []) if p['name'] == prop):
                 object_policy['properties'].append({'name': prop})
 
     def clear_object_load_policy(self, bo_name):
@@ -109,7 +110,12 @@ class RestBackend:
             return response.content  # todo: handle this better
 
     def _data_to_exception(self, data):
-        return dict(message=data['message'], code=data['code'], level=Severity(data['level']))
+        messages = data.get('messages', None)
+        inner_exs = ()
+        if messages:
+            data = messages[0]
+            inner_exs = [InnerException(**self._data_to_exception(m)) for m in messages[1:]]
+        return dict(message=data['message'], code=data['code'], level=Severity(data['level']), inner_exceptions=inner_exs)
 
     @staticmethod
     def eval_str_type(cls, field):
