@@ -14,7 +14,7 @@ class TcSoaConfig:
         if hasattr(sd, 'modelObjects') and sd.modelObjects:
             for uid, obj in sd.modelObjects.items():
                 if uid not in cls.__gobj_cache:
-                    cls.__gobj_cache[uid] = dict(uid=uid, type=obj['type'], className=['className'])
+                    cls.__gobj_cache[uid] = dict(uid=uid, type=obj['type'], className=obj['className'])
                 for pname, pval in obj.props.items():
                     cls.__gobj_cache[uid][pname] = pval
 
