@@ -1,4 +1,5 @@
 import enum
+from typing import List
 
 
 class Severity(enum.Enum):
@@ -9,11 +10,15 @@ class Severity(enum.Enum):
 
 
 class TcError(Exception):
-    def __init__(self, message: str, code: int, level: Severity):
-        super(TcError, self).__init__(f"[{level.name}] Code {code} - {message}")
+    def __init__(self, message: str, code: int, level: Severity, inner_exceptions: List['InnerException'] = ()):
         self.message = message
         self.code = code
         self.level = level
+        self.inner_exceptions = inner_exceptions
+        super(TcError, self).__init__()
+
+    def __str__(self):
+        return f"[{self.level.name}] Code {self.code} - {self.message}"
 
 
 class ServiceException(TcError):
@@ -26,3 +31,7 @@ class InvalidCredentialsException(TcError):
 
 class InternalServerException(TcError):
     pass
+
+
+class InnerException(TcError):
+    pass
