@@ -1,9 +1,9 @@
 from __future__ import annotations
 
 from tcsoa.gen.BusinessObjects import Cfg0ConfiguratorPerspective
-from tcsoa.gen.Configurator._2014_12.ConfiguratorManagement import GetAdmissibilityInputStruct, GetAdmissibilityResponse
+from tcsoa.gen.Configurator._2014_12.ConfiguratorManagement import GetAdmissibilityResponse, GetAdmissibilityInputStruct
 from typing import List
-from tcsoa.utils import TcService
+from tcsoa.base import TcService
 
 
 class ConfiguratorManagementService(TcService):
