@@ -1,5 +1,5 @@
 from tcsoa.gen.Configurator._2014_12.services import ConfiguratorManagementService as imp0
-from tcsoa.utils import TcService
+from tcsoa.base import TcService
 
 
 class ConfiguratorManagementService(TcService):
