@@ -10,13 +10,12 @@ from dataclasses import dataclass
 @dataclass
 class AttachedPropDescsResponse(TcBaseObj):
     """
-    AttachedPropDescsResponse  structure contains a map of PropDescOutput2 lists mapped to the input type name  and the
-    serviceData with possible errors.
+    Attached Property Descriptors Response
     
-    :var inputTypeNameToPropDescOutput: A map of property descriptor lists and the associated input type name.
-    :var serviceData: The Service Data.
+    :var inputTypeNameToPropDescOutput: Map of input type name to PropertyDescriptor
+    :var serviceData: ServiceData which has output tags as plain objects and errors in partialError
     """
-    inputTypeNameToPropDescOutput: InputTypeNameToPropDescOutputMap2 = None
+    inputTypeNameToPropDescOutput: InputTypeNameToPropDescOutputMap = None
     serviceData: ServiceData = None
 
 
@@ -31,7 +30,6 @@ class PropDesc(TcBaseObj):
     :var isModifiable: Specifies whether the property is modifiable
     :var attachedSpecifier: attachedSpecifier
     :var maxLength: maxLength
-    :var lovAttachmentsCategory: LOV attachments Category
     :var interdependentProps: interdependentProps
     :var defaultValue: Default value for the property
     :var propValueType: Value type for the property, PROP_untyped (0) No Value type PROP_char (1) Value is a single
@@ -55,7 +53,6 @@ class PropDesc(TcBaseObj):
     isModifiable: bool = False
     attachedSpecifier: int = 0
     maxLength: int = 0
-    lovAttachmentsCategory: int = 0
     interdependentProps: List[str] = ()
     defaultValue: str = ''
     propValueType: int = 0
@@ -68,7 +65,19 @@ class PropDesc(TcBaseObj):
 
 
 @dataclass
-class PropDescOutput2(TcBaseObj):
+class PropDescInfo(TcBaseObj):
+    """
+    PropDescInfo structure represents all the Property Names and associated type to retrieve Property Descriptors.
+    
+    :var typeName: The name of the type associated with the input Property Names.
+    :var propNames: A list of the input Property Names to retrieve Property Descriptors.
+    """
+    typeName: str = ''
+    propNames: List[str] = ()
+
+
+@dataclass
+class PropDescOutput(TcBaseObj):
     """
     Property Description Output
     
@@ -80,6 +89,6 @@ class PropDescOutput2(TcBaseObj):
 
 
 """
-InputTypeNameToPropDescOutputMap2
+InputTypeNameToPropDescOutputMap
 """
-InputTypeNameToPropDescOutputMap2 = Dict[str, List[PropDescOutput2]]
+InputTypeNameToPropDescOutputMap = Dict[str, List[PropDescOutput]]
