@@ -1,10 +1,10 @@
 from __future__ import annotations
 
-from tcsoa.gen.BusinessObjects import BusinessObject, Folder, Dataset, BOMLine
+from tcsoa.gen.BusinessObjects import BOMLine, BusinessObject, Folder, Dataset
 from enum import Enum
 from typing import List
 from tcsoa.gen.Server import ServiceData
-from tcsoa.utils import TcBaseObj
+from tcsoa.base import TcBaseObj
 from dataclasses import dataclass
 
 
