@@ -1,7 +1,7 @@
 from __future__ import annotations
 
 from tcsoa.gen.Internal.AuditManager._2012_09.ProcessHistoryManagement import GetProcessHistoryAuditRecordsResponse
-from tcsoa.utils import TcService
+from tcsoa.base import TcService
 from tcsoa.gen.BusinessObjects import WorkspaceObject
 
 
