@@ -1,7 +1,7 @@
 from tcsoa.gen.Internal_ChangeManagement._2015_03.services import ChangeManagementService as imp0
 from tcsoa.gen.Internal_ChangeManagement._2012_10.services import ChangeManagementService as imp1
 from tcsoa.gen.Internal_ChangeManagement._2020_01.services import MassUpdateService as imp2
-from tcsoa.utils import TcService
+from tcsoa.base import TcService
 
 
 class ChangeManagementService(TcService):
