@@ -1,7 +1,7 @@
 from __future__ import annotations
 
-from tcsoa.gen.Internal.RevRuleMgmt._2019_12.RevisionRuleAdministration import CreateUpdateRevRuleInput, RevRuleInfoResponse, CreateOrUpdateRevRuleResp
-from tcsoa.utils import TcService
+from tcsoa.gen.Internal.RevRuleMgmt._2019_12.RevisionRuleAdministration import CreateOrUpdateRevRuleResp, CreateUpdateRevRuleInput, RevRuleInfoResponse
+from tcsoa.base import TcService
 
 
 class RevisionRuleAdministrationService(TcService):
