@@ -1,5 +1,5 @@
 from tcsoa.gen.Internal_Structure._2020_12.services import WhereUsedService as imp0
-from tcsoa.utils import TcService
+from tcsoa.base import TcService
 
 
 class WhereUsedService(TcService):
