@@ -2,7 +2,7 @@ from __future__ import annotations
 
 from tcsoa.gen.OfficeOnline._2017_11.OfficeOnline import LaunchInfoOutputResponse, LaunchInfoInput
 from typing import List
-from tcsoa.utils import TcService
+from tcsoa.base import TcService
 
 
 class OfficeOnlineService(TcService):
